==> anwiba-commons-jdbc-1.0.180-sources.jar: net/anwiba/commons/jdbc/software/DatabaseSoftwareUtilities.java <==
/*
 * #%L
 * anwiba commons advanced
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.jdbc.software;

import java.util.Vector;

public class DatabaseSoftwareUtilities {

  public static ServiceDatabaseSoftware[] getGisSupportingTypes() {
    final Vector<ServiceDatabaseSoftware> dbTypeValues = new Vector<>();
    for (final ServiceDatabaseSoftware serviceDatabaseSoftware : ServiceDatabaseSoftware.values()) {
      if (serviceDatabaseSoftware.isApplicable() && serviceDatabaseSoftware.isGisSupportApplicable()) {
        dbTypeValues.add(serviceDatabaseSoftware);
      }
    }
    return dbTypeValues.toArray(new ServiceDatabaseSoftware[dbTypeValues.size()]);
  }

  public static ServiceDatabaseSoftware[] getApplicableTypes() {
    final Vector<ServiceDatabaseSoftware> dbTypeValues = new Vector<>();
    for (final ServiceDatabaseSoftware serviceDatabaseSoftware : ServiceDatabaseSoftware.values()) {
      if (serviceDatabaseSoftware.isApplicable() && serviceDatabaseSoftware.isGisSupportApplicable()) {
        dbTypeValues.add(serviceDatabaseSoftware);
      }
    }
    return dbTypeValues.toArray(new ServiceDatabaseSoftware[dbTypeValues.size()]);
  }

}

==> anwiba-commons-jdbc-1.2.50-sources.jar: net/anwiba/commons/jdbc/software/DatabaseSoftwareUtilities.java <==
/*
 * #%L
 * anwiba commons advanced
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.jdbc.software;

import java.util.List;
import java.util.Vector;

public class DatabaseSoftwareUtilities {

  public static List<ServiceDatabaseSoftware> getGisSupportingTypes() {
    final Vector<ServiceDatabaseSoftware> dbTypeValues = new Vector<>();
    for (final ServiceDatabaseSoftware serviceDatabaseSoftware : ServiceDatabaseSoftware.values()) {
      if (serviceDatabaseSoftware.isApplicable() && serviceDatabaseSoftware.isGisSupportApplicable()) {
        dbTypeValues.add(serviceDatabaseSoftware);
      }
    }
    return dbTypeValues;
  }

  public static List<ServiceDatabaseSoftware> getApplicableTypes() {
    final Vector<ServiceDatabaseSoftware> dbTypeValues = new Vector<>();
    for (final ServiceDatabaseSoftware serviceDatabaseSoftware : ServiceDatabaseSoftware.values()) {
      if (serviceDatabaseSoftware.isApplicable() && serviceDatabaseSoftware.isGisSupportApplicable()) {
        dbTypeValues.add(serviceDatabaseSoftware);
      }
    }
    return dbTypeValues;
  }

}
